=======
Credits
=======

Development Lead
----------------

* Iacopo Spalletti <i.spalletti@nephila.it>

Contributors
------------

* Adam Johnson
* Andrea Stagi
* Daniele Procida
* Eraldo Energy
* Felipe Prenholato
